@@ -14,3 +14,11 @@
 #undef HAVE_SETENV
 #undef HAVE_UNSETENV
 #undef HAVE_CLEARENV
+#undef EXPANDED_DATADIR
+#undef EXPANDED_PIXMAPDIR
+#undef EXPANDED_BINDIR
+#undef EXPANDED_GDMCONFIGDIR
+#undef EXPANDED_LOCALEDIR
+#undef EXPANDED_AUTHDIR
+#undef EXPANDED_SYSCONFDIR
+#undef EXPANDED_SESSDIR
