@@ -36,7 +36,7 @@
 #include "verify.h"
 #include "display.h"
 
-static const gchar RCSid[]="$Id: gdm.c,v 1.36 2001/05/24 22:32:01 jirka Exp $";
+static const gchar RCSid[]="$Id: gdm.c,v 1.40 2001/06/02 08:57:09 jirka Exp $";
 
 
 /* Local functions */
@@ -66,6 +66,7 @@ gboolean gdm_first_login = TRUE;
 gchar *GdmUser = NULL;
 gchar *GdmGroup = NULL;
 gchar *GdmSessDir = NULL;
+gchar *GdmLocaleFile = NULL;
 gchar *GdmGnomeDefaultSession = NULL;
 gchar *GdmAutomaticLogin = NULL;
 gboolean GdmAutomaticLoginEnable = FALSE;
@@ -107,6 +108,7 @@ gint  GdmPort = 0;
 gboolean  GdmIndirect = FALSE;
 gint  GdmMaxIndirect = 0;
 gint  GdmMaxIndirectWait = 0;
+gint  GdmPingInterval = 0;
 gboolean  GdmDebug = FALSE;
 gboolean  GdmVerboseAuth = FALSE;
 gboolean  GdmAllowRoot = FALSE;
@@ -175,6 +177,7 @@ gdm_config_parse (void)
     GdmDefaultLocale = gnome_config_get_string (GDM_KEY_LOCALE);
     GdmServAuthDir = gnome_config_get_string (GDM_KEY_SERVAUTH);
     GdmSessDir = gnome_config_get_string (GDM_KEY_SESSDIR);
+    GdmLocaleFile = gnome_config_get_string (GDM_KEY_LOCFILE);
     GdmGnomeDefaultSession = gnome_config_get_string (GDM_KEY_GNOMEDEFAULTSESSION);
     GdmUser = gnome_config_get_string (GDM_KEY_USER);
     GdmUserAuthDir = gnome_config_get_string (GDM_KEY_UAUTHDIR);
@@ -201,6 +204,7 @@ gdm_config_parse (void)
     GdmIndirect = gnome_config_get_bool (GDM_KEY_INDIRECT);
     GdmMaxIndirect = gnome_config_get_int (GDM_KEY_MAXINDIR);
     GdmMaxIndirectWait = gnome_config_get_int (GDM_KEY_MAXINDWAIT);    
+    GdmPingInterval = gnome_config_get_int (GDM_KEY_PINGINTERVAL);    
 
     GdmDebug = gnome_config_get_bool (GDM_KEY_DEBUG);
 
@@ -370,12 +374,11 @@ gdm_config_parse (void)
 	gdm_fail (_("gdm_config_parse: Authdir %s has wrong permissions. Should be 750. Aborting."), 
 		  GdmServAuthDir, statbuf.st_mode);
 
+    seteuid (0);
+    setegid (0);
 
     /* Check that user authentication is properly configured */
     gdm_verify_check ();
-
-    seteuid (0);
-    setegid (0);
 }
 
 
@@ -477,7 +480,7 @@ deal_with_x_crashes (GdmDisplay *d)
     if ( ! d->failsafe_xserver &&
 	 ! gdm_string_empty (GdmFailsafeXServer)) {
 	    char *bin = g_strdup (GdmFailsafeXServer);
-	    char *p = strchr (bin, argdelim);
+	    char *p = strchr (bin, argdelim[0]);
 	    if (p != NULL)
 		    *p = '\0';
 	    /* Yay we have a failsafe */
@@ -831,7 +834,7 @@ main (int argc, char *argv[])
     textdomain(PACKAGE);
 
     /* XDM compliant error message */
-    if (getuid())
+    if (getuid() != 0)
 	gdm_fail (_("Only root wants to run gdm\n"));
 
 
@@ -847,15 +850,20 @@ main (int argc, char *argv[])
     gdm_config_parse();
 
     /* Check if another gdm process is already running */
-    if (! access (GdmPidFile, R_OK)) {
+    if (access (GdmPidFile, R_OK) == 0) {
 
         /* Check if the existing process is still alive. */
         gint pidv;
 
         pf = fopen (GdmPidFile, "r");
 
-        if (pf && fscanf (pf, "%d", &pidv) == 1 && kill (pidv, 0) != -1)
+        if (pf != NULL &&
+	    fscanf (pf, "%d", &pidv) == 1 &&
+	    kill (pidv, 0) != -1)
 		gdm_fail (_("gdm already running. Aborting!"));
+
+	if (pf != NULL)
+		fclose (pf);
     }
 
     /* Become daemon unless started in -nodaemon mode or child of init */
