@@ -41,13 +41,14 @@
 #define SERVER_RUNNING 252	/* Server running and ready for connections */
 #define SERVER_ABORT 253	/* Server failed badly. Suspending display. */
 
+/* DO NOTE USE 1, that's used as error if x connection fails usually */
 #define DISPLAY_SUCCESS 0	/* All systems are go */
-#define DISPLAY_XFAILED 1	/* X failed */
 #define DISPLAY_REMANAGE 2	/* Restart display */
 #define DISPLAY_ABORT 4		/* Houston, we have a problem */
 #define DISPLAY_REBOOT 8	/* Rebewt */
 #define DISPLAY_HALT 16		/* Halt */
 #define DISPLAY_DEAD 32		/* Display not configured/started yet */
+#define DISPLAY_XFAILED 64	/* X failed */
 
 #define XDMCP_DEAD 0
 #define XDMCP_PENDING 1
@@ -69,6 +70,7 @@
 /* crap, these don't fit into the above theme, this protocol
  * is thus liable to change */
 #define GDM_GNOMESESS  '?'
+#define GDM_SGNOMESESS '*'
 #define GDM_STARTTIMER 's'
 #define GDM_STOPTIMER  'S'
 #define GDM_LOGIN      'L' /* this is the login prompt, much like PROMPT but
@@ -146,6 +148,7 @@
 #define GDM_KEY_INDIRECT "xdmcp/HonorIndirect=false"
 #define GDM_KEY_MAXINDIR "xdmcp/MaxPendingIndirect=4"
 #define GDM_KEY_MAXINDWAIT "xdmcp/MaxWaitIndirect=30"
+#define GDM_KEY_PINGINTERVAL "xdmcp/PingInterval=5"
 
 #define GDM_KEY_GTKRC "gui/GtkRC=" EXPANDED_DATADIR "/themes/Default/gtk/gtkrc"
 #define GDM_KEY_ICONWIDTH "gui/MaxIconWidth=128"
@@ -188,6 +191,9 @@
 
 #define GDM_KEY_SERVERS "servers"
 
+#define GDM_KEY_SHOW_GNOME_CHOOSER "greeter/ShowGnomeChooserSession=true"
+#define GDM_KEY_SHOW_GNOME_FAILSAFE "greeter/ShowGnomeFailsafeSession=true"
+#define GDM_KEY_SHOW_XTERM_FAILSAFE "greeter/ShowXtermFailsafeSession=true"
 
 #define GDM_SESSION_FAILSAFE_GNOME "GDM_Failsafe.GNOME"
 #define GDM_SESSION_FAILSAFE_XTERM "GDM_Failsafe.XTERM"
