@@ -31,7 +31,7 @@
 #include "slave.h"
 #include "verify.h"
 
-static const gchar RCSid[]="$Id: verify-shadow.c,v 1.10 2001/04/30 23:48:11 jirka Exp $";
+static const gchar RCSid[]="$Id: verify-shadow.c,v 1.11 2001/05/13 06:44:29 jirka Exp $";
 
 
 /* Configuration option variables */
@@ -84,19 +84,26 @@ gdm_verify_user (const char *username, const gchar *display, gboolean local)
     
     if (sp)
 	ppasswd = sp->sp_pwdp;
+    else
+	ppasswd = NULL;
     
     endspent();
 
     /* Request the user's password */
-    passwd = gdm_slave_greeter_ctl (GDM_NOECHO, _("Password: "));
-    if (passwd == NULL)
+    if (gdm_string_empty (ppasswd)) {
+	    /* eeek a passwordless account */
 	    passwd = g_strdup ("");
-    if (gdm_slave_greeter_check_interruption (passwd)) {
-	    if (local)
-		    gdm_slave_greeter_ctl_no_ret (GDM_STOPTIMER, "");
-	    g_free (login);
-	    g_free (passwd);
-	    return NULL;
+    } else {
+	    passwd = gdm_slave_greeter_ctl (GDM_NOECHO, _("Password: "));
+	    if (passwd == NULL)
+		    passwd = g_strdup ("");
+	    if (gdm_slave_greeter_check_interruption (passwd)) {
+		    if (local)
+			    gdm_slave_greeter_ctl_no_ret (GDM_STOPTIMER, "");
+		    g_free (login);
+		    g_free (passwd);
+		    return NULL;
+	    }
     }
 
     if (local)
@@ -108,6 +115,15 @@ gdm_verify_user (const char *username, const gchar *display, gboolean local)
 	    return NULL;
     }
 
+    /* Check whether password is valid */
+    if (ppasswd == NULL || (ppasswd[0] != '\0' &&
+			    strcmp (crypt (passwd, ppasswd), ppasswd) != 0)) {
+	    gdm_slave_greeter_ctl_no_ret (GDM_MSGERR, _("Login incorrect"));
+	    g_free (login);
+	    g_free (passwd);
+	    return NULL;
+    }
+
     if ( ( ! GdmAllowRoot ||
 	  ( ! GdmAllowRemoteRoot && ! local) ) &&
 	pwent->pw_uid == 0) {
@@ -119,6 +135,8 @@ gdm_verify_user (const char *username, const gchar *display, gboolean local)
 		    gdm_slave_greeter_ctl_no_ret (GDM_MSGERR,
 						  _("Login incorrect"));
 	    }
+	    g_free (login);
+	    g_free (passwd);
 	    return NULL;
     }
 
@@ -133,14 +151,11 @@ gdm_verify_user (const char *username, const gchar *display, gboolean local)
 		    gdm_slave_greeter_ctl_no_ret (GDM_MSGERR,
 						  _("Login incorrect"));
 	    }
+	    g_free (login);
+	    g_free (passwd);
 	    return NULL;
     }	
-
-    /* Check whether password is valid */
-    if (!passwd || !ppasswd || strcmp (crypt (passwd, ppasswd), ppasswd)) {
-	    gdm_slave_greeter_ctl_no_ret (GDM_MSGERR, _("Login incorrect"));
-	    return NULL;
-    }
+    g_free (passwd);
 
     return login;
 }
