@@ -48,14 +48,14 @@
 #include "gdm.h"
 #include "misc.h"
 
-/* set the DOING_GDM_DEVELOPMENT env variable to "yes" if you want to
+/* set the DOING_GDM_DEVELOPMENT env variable if you want to
  * search for the glade file in the current dir and not the system
  * install dir, better then something you have to change
  * in the source and recompile */
 static gboolean DOING_GDM_DEVELOPMENT = FALSE;
 
 
-static const gchar RCSid[]="$Id: gdmchooser.c,v 1.13 2001/05/04 01:27:20 jirka Exp $";
+static const gchar RCSid[]="$Id: gdmchooser.c,v 1.15 2001/05/21 18:30:37 jirka Exp $";
 
 static const gchar *scanning_message = N_("Please wait: scanning local network for XDMCP-enabled hosts...");
 static const gchar *empty_network = N_("No serving hosts were found.");
@@ -504,9 +504,14 @@ gdm_chooser_gui_init (void)
      */
 	
     if ( ! DOING_GDM_DEVELOPMENT) {
-	    glade_filename = gnome_datadir_file("gdm/gdmchooser.glade");
-	    if (glade_filename == NULL) {	  
-		    glade_filename = g_strdup("gdmchooser.glade");
+	    if (g_file_exists (GDM_GLADE_DIR "/gdmchooser.glade")) {
+		    glade_filename = g_strdup (GDM_GLADE_DIR
+					       "/gdmchooser.glade");
+	    } else {
+		    glade_filename = gnome_datadir_file("gdm/gdmchooser.glade");
+		    if (glade_filename == NULL) {	  
+			    glade_filename = g_strdup("gdmchooser.glade");
+		    }
 	    }
     } else {
 	    glade_filename = g_strdup("gdmchooser.glade");
@@ -816,8 +821,7 @@ main (int argc, char *argv[])
     gchar **hosts;
     poptContext ctx;
 
-    if (g_getenv ("DOING_GDM_DEVELOPMENT") != 0 &&
-	strcasecmp_no_locale (g_getenv ("DOING_GDM_DEVELOPMENT"), "yes") == 0)
+    if (g_getenv ("DOING_GDM_DEVELOPMENT") != NULL)
 	    DOING_GDM_DEVELOPMENT = TRUE;
 
     /* Avoid creating ~gdm/.gnome stuff */
