@@ -50,7 +50,7 @@
  * within the protocol */
 static gboolean DOING_GDM_DEVELOPMENT = FALSE;
 
-static const gchar RCSid[]="$Id: gdmlogin.c,v 1.78 2001/05/24 22:32:02 jirka Exp $";
+static const gchar RCSid[]="$Id: gdmlogin.c,v 1.83 2001/05/31 18:37:45 hp Exp $";
 
 /* Some strings that are in other files that we may want to
  * translate.  This is not actually used anywhere, it's just
@@ -111,12 +111,17 @@ static gint GdmPositionX;
 static gint GdmPositionY;
 static gboolean GdmTitleBar;
 
+static gboolean GdmShowGnomeChooserSession;
+static gboolean GdmShowGnomeFailsafeSession;
+static gboolean GdmShowXtermFailsafeSession;
+
 static GtkWidget *login;
 static GtkWidget *label;
 static GtkWidget *clock_label = NULL;
 static GtkWidget *entry;
 static GtkWidget *msg;
 static gboolean require_quarter = FALSE;
+static gboolean remember_gnome_session = FALSE;
 static GtkWidget *icon_win = NULL;
 static GtkWidget *sessmenu;
 static GtkWidget *langmenu;
@@ -127,6 +132,8 @@ static GtkTooltips *tooltips;
 static gboolean login_is_local = FALSE;
 static gboolean used_defaults = FALSE;
 
+
+
 GdkRectangle screen; /* this is an extern since it's used in gdmwm as well */
 
 static GnomeIconList *browser;
@@ -765,6 +772,10 @@ gdm_login_parse_config (void)
     GdmPositionX = gnome_config_get_int (GDM_KEY_POSITIONX);
     GdmPositionY = gnome_config_get_int (GDM_KEY_POSITIONY);
 
+    GdmShowXtermFailsafeSession = gnome_config_get_bool (GDM_KEY_SHOW_XTERM_FAILSAFE);
+    GdmShowGnomeFailsafeSession = gnome_config_get_bool (GDM_KEY_SHOW_GNOME_FAILSAFE);
+    GdmShowGnomeChooserSession = gnome_config_get_bool (GDM_KEY_SHOW_GNOME_CHOOSER);
+    
     GdmTimedLoginEnable = gnome_config_get_bool (GDM_KEY_TIMED_LOGIN_ENABLE);
     if (GdmTimedLoginEnable) {
 	    GdmTimedLogin = gnome_config_get_string (GDM_KEY_TIMED_LOGIN);
@@ -1169,7 +1180,7 @@ gdm_login_session_init (GtkWidget *menu)
     cursess = LAST_SESSION;
     item = gtk_radio_menu_item_new_with_label (NULL, _(LAST_SESSION));
     gtk_object_set_data (GTK_OBJECT (item),
-			 "SessionName",
+			 SESSION_NAME,
 			 LAST_SESSION);
     sessgrp = gtk_radio_menu_item_group (GTK_RADIO_MENU_ITEM (item));
     gtk_menu_append (GTK_MENU (menu), item);
@@ -1211,6 +1222,7 @@ gdm_login_session_init (GtkWidget *menu)
 	/* Ignore backups and rpmsave files */
 	if ((strstr (dent->d_name, "~")) ||
 	    (strstr (dent->d_name, ".rpmsave")) ||
+	    (strstr (dent->d_name, ".rpmorig")) ||
 	    (strstr (dent->d_name, ".dpkg-old")) ||
 	    (strstr (dent->d_name, ".deleted")) ||
 	    (strstr (dent->d_name, ".desc")) /* description file */ ||
@@ -1244,7 +1256,7 @@ gdm_login_session_init (GtkWidget *menu)
 	    {
 		item = gtk_radio_menu_item_new_with_label (sessgrp, _(dent->d_name));
 		gtk_object_set_data_full (GTK_OBJECT (item),
-					  "SessionName",
+					  SESSION_NAME,
 					  g_strdup (dent->d_name),
 					  (GtkDestroyNotify) g_free);
 
@@ -1278,30 +1290,35 @@ gdm_login_session_init (GtkWidget *menu)
 				   "GNOME, into your current session."),
 				 NULL);
 
-			/* Add the chooser session, this one doesn't have a script
-			 * really, it's a fake, it runs the Gnome script */
-			/* For translators:  This is the login that lets users choose the
-			 * specific gnome session they want to use */
-			item = gtk_radio_menu_item_new_with_label (sessgrp, _("Gnome Chooser"));
-			gtk_tooltips_set_tip
-				(tooltips, GTK_WIDGET (item),
-				 _("This session will log you into "
-				   "GNOME and it will let you choose which "
-				   "one of the GNOME sessions you want to "
-				   "use."),
-				 NULL);
-			gtk_object_set_data (GTK_OBJECT (item),
-					     "SessionName",
-					     GDM_SESSION_GNOME_CHOOSER);
+                        if (GdmShowGnomeChooserSession) {
+                                /* Add the chooser session, this one doesn't have a
+                                 * script really, it's a fake, it runs the Gnome
+                                 * script */
+                                /* For translators:  This is the login that lets
+                                 * users choose the specific gnome session they
+                                 * want to use */
+                                item = gtk_radio_menu_item_new_with_label
+                                        (sessgrp, _("Gnome Chooser"));
+                                gtk_tooltips_set_tip
+                                        (tooltips, GTK_WIDGET (item),
+                                         _("This session will log you into "
+                                           "GNOME and it will let you choose which "
+                                           "one of the GNOME sessions you want to "
+                                           "use."),
+                                         NULL);
+                                gtk_object_set_data (GTK_OBJECT (item),
+                                                     SESSION_NAME,
+                                                     GDM_SESSION_GNOME_CHOOSER);
 
-			sessgrp = gtk_radio_menu_item_group (GTK_RADIO_MENU_ITEM (item));
-			sessions = g_slist_append (sessions,
-						   g_strdup (GDM_SESSION_GNOME_CHOOSER));
-			gtk_menu_append (GTK_MENU (menu), item);
-			gtk_signal_connect (GTK_OBJECT (item), "activate",
-					    GTK_SIGNAL_FUNC (gdm_login_session_handler),
-					    NULL);
-			gtk_widget_show (GTK_WIDGET (item));
+                                sessgrp = gtk_radio_menu_item_group (GTK_RADIO_MENU_ITEM (item));
+                                sessions = g_slist_append (sessions,
+                                                           g_strdup (GDM_SESSION_GNOME_CHOOSER));
+                                gtk_menu_append (GTK_MENU (menu), item);
+                                gtk_signal_connect (GTK_OBJECT (item), "activate",
+                                                    GTK_SIGNAL_FUNC (gdm_login_session_handler),
+                                                    NULL);
+                                gtk_widget_show (GTK_WIDGET (item));
+                        }
 		}
 			
 	    }
@@ -1325,52 +1342,56 @@ gdm_login_session_init (GtkWidget *menu)
 	    defsess = g_strdup (GDM_SESSION_FAILSAFE_GNOME);
     }
 
-    /* For translators:  This is the failsafe login when the user
-     * can't login otherwise */
-    item = gtk_radio_menu_item_new_with_label (sessgrp,
-					       _("Failsafe Gnome"));
-    gtk_tooltips_set_tip (tooltips, GTK_WIDGET (item),
-		          _("This is a failsafe session that will log you "
-			    "into GNOME.  No startup scripts will be read "
-			    "and it is only to be used when you can't log "
-			    "in otherwise.  GNOME will use the 'Default' "
-			    "session."),
-			  NULL);
-    gtk_object_set_data (GTK_OBJECT (item),
-			 "SessionName", GDM_SESSION_FAILSAFE_GNOME);
+    if (GdmShowGnomeFailsafeSession) {
+            /* For translators:  This is the failsafe login when the user
+             * can't login otherwise */
+            item = gtk_radio_menu_item_new_with_label (sessgrp,
+                                                       _("Failsafe Gnome"));
+            gtk_tooltips_set_tip (tooltips, GTK_WIDGET (item),
+                                  _("This is a failsafe session that will log you "
+                                    "into GNOME.  No startup scripts will be read "
+                                    "and it is only to be used when you can't log "
+                                    "in otherwise.  GNOME will use the 'Default' "
+                                    "session."),
+                                  NULL);
+            gtk_object_set_data (GTK_OBJECT (item),
+                                 SESSION_NAME, GDM_SESSION_FAILSAFE_GNOME);
 
-    sessgrp = gtk_radio_menu_item_group (GTK_RADIO_MENU_ITEM (item));
-    sessions = g_slist_append (sessions,
-			       g_strdup (GDM_SESSION_FAILSAFE_GNOME));
-    gtk_menu_append (GTK_MENU (menu), item);
-    gtk_signal_connect (GTK_OBJECT (item), "activate",
-			GTK_SIGNAL_FUNC (gdm_login_session_handler),
-			NULL);
-    gtk_widget_show (GTK_WIDGET (item));
+            sessgrp = gtk_radio_menu_item_group (GTK_RADIO_MENU_ITEM (item));
+            sessions = g_slist_append (sessions,
+                                       g_strdup (GDM_SESSION_FAILSAFE_GNOME));
+            gtk_menu_append (GTK_MENU (menu), item);
+            gtk_signal_connect (GTK_OBJECT (item), "activate",
+                                GTK_SIGNAL_FUNC (gdm_login_session_handler),
+                                NULL);
+            gtk_widget_show (GTK_WIDGET (item));
+    }
 
-    /* For translators:  This is the failsafe login when the user
-     * can't login otherwise */
-    item = gtk_radio_menu_item_new_with_label (sessgrp,
-					       _("Failsafe xterm"));
-    gtk_tooltips_set_tip (tooltips, GTK_WIDGET (item),
-		          _("This is a failsafe session that will log you "
-			    "into a terminal.  No startup scripts will be read "
-			    "and it is only to be used when you can't log "
-			    "in otherwise.  To exit the terminal, "
-			    "type 'exit'."),
-			  NULL);
-    gtk_object_set_data (GTK_OBJECT (item),
-			 "SessionName", GDM_SESSION_FAILSAFE_XTERM);
-
-    sessgrp = gtk_radio_menu_item_group (GTK_RADIO_MENU_ITEM (item));
-    sessions = g_slist_append (sessions,
-			       g_strdup (GDM_SESSION_FAILSAFE_XTERM));
-    gtk_menu_append (GTK_MENU (menu), item);
-    gtk_signal_connect (GTK_OBJECT (item), "activate",
-			GTK_SIGNAL_FUNC (gdm_login_session_handler),
-			NULL);
-    gtk_widget_show (GTK_WIDGET (item));
+    if (GdmShowXtermFailsafeSession) {
+            /* For translators:  This is the failsafe login when the user
+             * can't login otherwise */
+            item = gtk_radio_menu_item_new_with_label (sessgrp,
+                                                       _("Failsafe xterm"));
+            gtk_tooltips_set_tip (tooltips, GTK_WIDGET (item),
+                                  _("This is a failsafe session that will log you "
+                                    "into a terminal.  No startup scripts will be read "
+                                    "and it is only to be used when you can't log "
+                                    "in otherwise.  To exit the terminal, "
+                                    "type 'exit'."),
+                                  NULL);
+            gtk_object_set_data (GTK_OBJECT (item),
+                                 SESSION_NAME, GDM_SESSION_FAILSAFE_XTERM);
 
+            sessgrp = gtk_radio_menu_item_group (GTK_RADIO_MENU_ITEM (item));
+            sessions = g_slist_append (sessions,
+                                       g_strdup (GDM_SESSION_FAILSAFE_XTERM));
+            gtk_menu_append (GTK_MENU (menu), item);
+            gtk_signal_connect (GTK_OBJECT (item), "activate",
+                                GTK_SIGNAL_FUNC (gdm_login_session_handler),
+                                NULL);
+            gtk_widget_show (GTK_WIDGET (item));
+    }
+                    
     if (defsess == NULL) {
 	    defsess = g_strdup (GDM_SESSION_FAILSAFE_GNOME);
 	    syslog (LOG_WARNING, _("No default session link found. Using Failsafe GNOME.\n"));
@@ -1550,6 +1571,7 @@ get_gnome_session (const char *sess_string)
 	GtkWidget *hbox;
 	GtkWidget *entry;
 	GtkWidget *newcb;
+	GtkWidget *remembercb;
 	char *retval;
 	char **sessions;
 	char *selected;
@@ -1671,6 +1693,14 @@ get_gnome_session (const char *sess_string)
 			    GTK_SIGNAL_FUNC (toggle_insensitize),
 			    clist);
 
+	remembercb = gtk_check_button_new_with_label
+		/* Translators: this is to remember the chosen gnome session
+		 * for next time */
+	       	(_("Remember this setting"));
+	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (remembercb), TRUE);
+	gtk_box_pack_start (GTK_BOX (GNOME_DIALOG (d)->vbox), remembercb,
+			    FALSE, FALSE, 0);
+
 	gtk_window_set_modal (GTK_WINDOW (d), TRUE);
 
 	gtk_widget_show_all (d);
@@ -1680,6 +1710,8 @@ get_gnome_session (const char *sess_string)
 	gnome_dialog_run (GNOME_DIALOG (d));
 	gdm_wm_no_login_focus_pop ();
 
+	remember_gnome_session = GTK_TOGGLE_BUTTON (remembercb)->active;
+
 	/* we've set the just_hide to TRUE, so we can still access the
 	 * window */
 	if (GTK_TOGGLE_BUTTON (newcb)->active) {
@@ -1816,7 +1848,7 @@ gdm_login_ctrl_handler (GIOChannel *source, GIOCondition cond, gint fd)
 	g_io_channel_read (source, buf, PIPE_SIZE-1, &len);
 	buf[len-1] = '\0';
 
-	/* HAAAAAAACK.  Sometimes pam send many many messages, SO
+	/* HAAAAAAACK.  Sometimes pam sends many many messages, SO
 	 * we try to collect them until the next prompt or reset or
 	 * whatnot */
 	if ( ! replace_msg) {
@@ -1890,6 +1922,7 @@ gdm_login_ctrl_handler (GIOChannel *source, GIOCondition cond, gint fd)
 			usleep (200);
 		}
 	}
+	/* fall thru to reset */
 
     case GDM_RESETOK:
 	g_io_channel_read (source, buf, PIPE_SIZE-1, &len);
@@ -1969,6 +2002,16 @@ gdm_login_ctrl_handler (GIOChannel *source, GIOCondition cond, gint fd)
 	}
 	break;
 
+    case GDM_SGNOMESESS:
+	g_io_channel_read (source, buf, PIPE_SIZE-1, &len); /* Empty */
+
+	if (remember_gnome_session)
+	    g_print ("%cY\n", STX);
+	else
+	    g_print ("%c\n", STX);
+
+	break;
+
     case GDM_STARTTIMER:
 	g_io_channel_read (source, buf, PIPE_SIZE-1, &len); /* Empty */
 
@@ -2206,6 +2249,30 @@ gdm_login_handle_motion (GtkWidget *widget, GdkEventMotion *event)
     return TRUE;
 }
 
+static gboolean
+minimize_expose (GtkWidget *icon, GdkEventExpose *event, gpointer data)
+{
+	if (icon->window != NULL) {
+		gtk_paint_flat_box (icon->style,
+				    icon->window,
+				    icon->state,
+				    GTK_SHADOW_NONE,
+				    &event->area,
+				    icon,
+				    "gdm-iconify",
+				    0, 0,
+				    icon->allocation.width,
+				    icon->allocation.height);
+		gdk_draw_rectangle (icon->window,
+				    icon->style->text_gc[icon->state],
+				    TRUE /* filled */,
+				    3				/* x */,
+				    icon->allocation.height - 6 /* y */,
+				    icon->allocation.width - 6	/* width */,
+				    3				/* height */);
+	}
+	return TRUE;
+}
 
 static GtkWidget *
 create_handle (void)
@@ -2250,11 +2317,15 @@ create_handle (void)
 		if (access (GdmIcon, R_OK)) {
 			syslog (LOG_WARNING, _("Can't open icon file: %s. Suspending iconify feature!"), GdmIcon);
 		} else {
+			GtkWidget *icon;
 			w = gtk_button_new ();
-			gtk_button_set_relief (GTK_BUTTON (w), GTK_RELIEF_NONE);
-			gtk_container_add (GTK_CONTAINER (w),
-					   gtk_arrow_new (GTK_ARROW_DOWN,
-							  GTK_SHADOW_OUT));
+			gtk_container_border_width (GTK_CONTAINER (w), 2);
+			icon = gtk_drawing_area_new ();
+			gtk_signal_connect (GTK_OBJECT (icon), "expose_event",
+					    GTK_SIGNAL_FUNC (minimize_expose),
+					    NULL);
+			gtk_widget_set_usize (icon, 16, -1);
+			gtk_container_add (GTK_CONTAINER (w), icon);
 			gtk_signal_connect
 				(GTK_OBJECT (w), "clicked",
 				 GTK_SIGNAL_FUNC (gdm_login_iconify_handler), 
